# Independent

Independent is a basic Python package with no dependencies. In other words, Independent is not dependent on any other
external packages.

You can install Independent by pip as:
```
python -m pip install independent
```

## Contacts

Dr Carmelo Calafiore

Newcastle University

Newcastle, UK

[dr.carmelo.calafiore@gmail.com](mailto:dr.carmelo.calafiore@gmail.com)

[LinkedIn](https://www.linkedin.com/in/carmelo-calafiore-a07120269)

[GitHub](https://github.com/ccalafiore)
